@@ -1,4 +1,4 @@
-VERSION = (1, 1, 21, 'stable')
+VERSION = (1, 1, 30, 'stable')
 
 def get_version():
     return '%d.%d.%d-%s'%VERSION
@@ -9,3 +9,8 @@ __license__ = 'GNU Lesser General Public License (LGPL)'
 __url__ = 'http://django-plus.googlecode.com'
 __version__ = get_version()
 
+def get_dynamic_template(slug, context=None):
+    from models import DynamicTemplate
+
+    return DynamicTemplate.objects.get(slug=slug).render(context or {})
+
