@@ -30,7 +30,7 @@ class ProtectAntiRobotsMiddleware(object):
     def process_request(self, request):
         current_domain = app_settings.ROBOT_PROTECTION_DOMAIN
 
-        if request.get_full_path().startswith('/protectantirobots/'):
+        if request.path_info.startswith('/protectantirobots/'):
             path = request.GET.get('path', '') or request.POST.get('path', '')
             if request.path == '/protectantirobots/img/':
                 s = base64.b64decode(request.COOKIES['protectantirobots_key_'+path])
