@@ -9,7 +9,7 @@ from django.conf import settings
 from django.template.defaultfilters import slugify
 from django.core.cache import cache
 
-from djangoplus.utils import path_to_object, split1000
+from djangoplus.utils import path_to_object, split1000, get_admin_url
 from djangoplus import app_settings
 
 register = Library()
@@ -167,6 +167,18 @@ def replace(value,arg):
     args = arg.split(',')
     return value.replace(args[0], args[1])
 
+@register.filter
+def is_lower(value):
+    return value == value.lower()
+
+@register.filter
+def is_upper(value):
+    return value == value.upper()
+
+@register.filter
+def is_capitalized(value):
+    return value == value.capitalize()
+
 """
 Miscelanea
 """
@@ -293,6 +305,10 @@ def has_module_perm(user, app_label):
 
     return user.has_module_perms(app_label)
 
+@register.filter
+def admin_url(obj):
+    return get_admin_url(obj)
+
 """
 TAMPLATE TAGS
 """
@@ -654,6 +670,8 @@ def do_includefromurl(parser, token):
 
 register.tag('includefromurl', do_includefromurl)
 
+# Ajax FK Widget
+
 class AjaxFKWidgetCellsRender(template.Node):
     vobj = None
     vfields = None
@@ -684,3 +702,7 @@ def do_ajaxfkwidget_cells(parser, token):
 
 register.tag('ajaxfkwidget_cells', do_ajaxfkwidget_cells)
 
+@register.filter
+def ajaxfkwidget_url(obj, func):
+    return func(obj)
+
